@@ -97,6 +97,9 @@ class GenericViewer(Viewer):
         # whether the library has been changed
         self.__lib_is_dirty = False
         
+        # whether we may advance to the next track
+        self.__may_go_next = True
+        
     
         Viewer.__init__(self)
         
@@ -265,6 +268,8 @@ class GenericViewer(Viewer):
         
         # show playable items
         elif (self.__view_mode == self._VIEWMODE_PLAYER_NORMAL):
+            import time
+            print time.time()
             for entry in self.__playable_items:
                 icon, uptodate = self.call_service(
                                     msgs.MEDIASCANNER_SVC_GET_THUMBNAIL, entry)
@@ -272,6 +277,7 @@ class GenericViewer(Viewer):
                 tn = FileThumbnail(icon, entry)
                 strip_items.append(tn)
             #end for
+            print time.time()
             
             if (self.__current_file in self.__playable_items):
                 strip_index = self.__playable_items.index(self.__current_file)           
@@ -393,7 +399,7 @@ class GenericViewer(Viewer):
 
         if (mode == self._VIEWMODE_BROWSER):
             self.emit_event(msgs.UI_ACT_FREEZE)
-            self.emit_event(msgs.CORE_ACT_VIEW_MODE, viewmodes.NORMAL)
+            self.emit_event(msgs.UI_ACT_VIEW_MODE, viewmodes.NORMAL)
             
             #if (self.__path_stack):
             #    self.__load_folder(self.__path_stack[-1][0], None)
@@ -414,7 +420,7 @@ class GenericViewer(Viewer):
 
         elif (mode == self._VIEWMODE_SPLIT_BROWSER):
             self.emit_event(msgs.UI_ACT_FREEZE)
-            self.emit_event(msgs.CORE_ACT_VIEW_MODE, viewmodes.NORMAL)
+            self.emit_event(msgs.UI_ACT_VIEW_MODE, viewmodes.NORMAL)
 
             #if (self.__path_stack):
             #    self.__load_folder(self.__path_stack[-1][0], None)
@@ -434,24 +440,23 @@ class GenericViewer(Viewer):
 
 
         elif (mode == self._VIEWMODE_PLAYER_NORMAL):
-            self.emit_event(msgs.CORE_ACT_VIEW_MODE, viewmodes.NORMAL)
+            self.emit_event(msgs.UI_ACT_VIEW_MODE, viewmodes.NORMAL)
             self.__media_box.set_visible(True)
             self.__side_tabs.set_visible(True)
             self.__list.set_visible(False)
             self.__lib_list.set_visible(False)
             
-            if (was_fullscreen):
-                self.render()          
-            self.emit_event(msgs.UI_ACT_FREEZE)
-            
-            self.__update_side_strip()
-            self.__hilight_current_file()
-            self.__update_toolbar()
-            if (self.__current_file):
-                self.set_title(self.__current_file.name)
-
-            #gobject.timeout_add(50, self.emit_event, msgs.UI_ACT_THAW)
-            self.emit_event(msgs.UI_ACT_THAW)
+            if (not was_fullscreen):
+                self.emit_event(msgs.UI_ACT_FREEZE)
+                self.__update_side_strip()
+                self.__hilight_current_file()
+                self.__update_toolbar()
+                if (self.__current_file):
+                    self.set_title(self.__current_file.name)
+                self.emit_event(msgs.UI_ACT_THAW)
+            else:
+                self.render()
+                gobject.timeout_add(50, self.emit_event, msgs.UI_ACT_RENDER)
 
 
         elif (mode == self._VIEWMODE_PLAYER_FULLSCREEN):
@@ -460,7 +465,7 @@ class GenericViewer(Viewer):
             self.__lib_list.set_visible(False)
             self.__media_box.set_visible(True)
             self.__media_box.set_geometry(0, 0, 800, 480)
-            self.emit_event(msgs.CORE_ACT_VIEW_MODE, viewmodes.FULLSCREEN)
+            self.emit_event(msgs.UI_ACT_VIEW_MODE, viewmodes.FULLSCREEN)
 
             #self.emit_event(msgs.UI_ACT_THAW)
             self.render()
@@ -468,7 +473,7 @@ class GenericViewer(Viewer):
 
         elif (mode == self._VIEWMODE_LIBRARY):           
             self.emit_event(msgs.UI_ACT_FREEZE)
-            self.emit_event(msgs.CORE_ACT_VIEW_MODE, viewmodes.NO_STRIP)
+            self.emit_event(msgs.UI_ACT_VIEW_MODE, viewmodes.NO_STRIP)
             
             self.__side_tabs.set_visible(True)
             self.__list.set_visible(False)
@@ -504,7 +509,7 @@ class GenericViewer(Viewer):
                 self.__media_widget.close()
         
         if (msg == msgs.MEDIASCANNER_EV_SCANNING_FINISHED):
-            if (self.__current_device):
+            if (self.__current_device and self.__path_stack):
                 #self.__load_device(self.__current_device)
                 path = self.__path_stack[-1][0]
                 self.__load_folder(path, None)
@@ -526,6 +531,7 @@ class GenericViewer(Viewer):
         elif (msg == msgs.MEDIA_EV_LOADED):
             self.__list.hilight(-1)
             self.__current_file = None
+            self.__may_go_next = False
         
         
         
@@ -582,6 +588,13 @@ class GenericViewer(Viewer):
             key = args[0]
             self.__search(key)
 
+        # select a device
+        elif (msg == msgs.UI_ACT_SELECT_DEVICE):
+            dev_id = args[0]
+            if (dev_id in self.__devices):
+                self.__load_device(self.__devices[dev_id])
+                self.__update_side_strip()
+
 
         # go to previous
         elif (msg == msgs.MEDIA_ACT_PREVIOUS):
@@ -745,8 +758,14 @@ class GenericViewer(Viewer):
         self.__path_stack = []
         
         root = device.get_root()
+        print "LOAD DEVICE", device, root
         self.set_title(device.get_name())
-        self.__load_folder(root, self.__GO_NEW)
+        if (root.mimetype == root.DIRECTORY):
+            self.__load_folder(root, self.__GO_NEW)
+        else:
+            self.__load_file(root, self.__GO_NEW)
+            
+        self.emit_event(msgs.UI_EV_DEVICE_SELECTED, device.get_device_id())
 
 
 
@@ -898,8 +917,8 @@ class GenericViewer(Viewer):
         header.set_buttons(*buttons)
         self.__list.append_item(header)
         self.__update_toolbar()
-        self.__list.render()
-        #self.emit_event(msgs.UI_ACT_RENDER)
+        #self.__list.render()
+        self.emit_event(msgs.UI_ACT_RENDER)
         
         if (self.__view_mode == self._VIEWMODE_SPLIT_BROWSER):
             if (len(self.__path_stack) > 1):
@@ -952,7 +971,7 @@ class GenericViewer(Viewer):
 
         # change item button
         item = self.__list.get_item(idx + 1)
-        item.set_buttons((item.BUTTON_CLOSE, theme.mb_item_btn_close),
+        item.set_buttons(#(item.BUTTON_CLOSE, theme.mb_item_btn_close),
                          (item.BUTTON_ENQUEUE, theme.mb_item_btn_enqueue))
 
         gobject.timeout_add(0, path.get_children_async, on_child,
@@ -974,6 +993,7 @@ class GenericViewer(Viewer):
         item.set_buttons((item.BUTTON_OPEN, theme.mb_item_btn_open))
         
         self.__subfolder_range = None
+        self.__list.render()
 
 
     def __add_file(self, entry, items_to_thumbnail, insert_at):
@@ -1047,8 +1067,11 @@ class GenericViewer(Viewer):
         """
         
         logging.debug("reached EOF")
+        self.__may_go_next = True
+        
         self.emit_event(msgs.MEDIA_EV_EOF)
-        if (self.may_go_next()):
+
+        if (self.__may_go_next):
             logging.debug("going to next item")
             self.__go_next()
 
@@ -1151,8 +1174,11 @@ class GenericViewer(Viewer):
         """
         Reacts on pressing the [Back] button.
         """
-    
-        if (len(self.__path_stack) > 1):
+
+        if (self.__subfolder_range):
+            self.__close_subfolder()
+        
+        elif (len(self.__path_stack) > 1):
             self.__path_stack.pop()
             path, list_offset = self.__path_stack.pop()
             self.__load_folder(path, self.__GO_PARENT)
@@ -1299,6 +1325,7 @@ class GenericViewer(Viewer):
                                   on_created, item, tn)
 
             #end if
+    
         #end if
 
 
@@ -1319,7 +1346,7 @@ class GenericViewer(Viewer):
     def show(self):
         
         def f():
-            if (self.may_render()):
+            if (self.may_render() and not self.__current_device):
                 self.select_strip_item(0)
                 return False
             else:
