@@ -246,10 +246,15 @@ class AudioWidget(MediaWidget):
             self.__btn_play.set_images(theme.mb_btn_play_1,
                                        theme.mb_btn_play_2)
 
-        elif (cmd == src.OBS_BUFFERING):
+        elif (cmd == src.OBS_CONNECTING):
             ctx = args[0]
             if (ctx == self.__context_id):
-                self.__progress.set_message("... buffering ...")
+                self.__progress.set_message("... connecting ...")
+
+        elif (cmd == src.OBS_BUFFERING):
+            ctx, value = args
+            if (ctx == self.__context_id):
+                self.__progress.set_message("... buffering (%d%%)..." % value)
 
         elif (cmd == src.OBS_ERROR):
             ctx, err = args
@@ -291,8 +296,9 @@ class AudioWidget(MediaWidget):
                 self.__cover.set_active(True)
                 self.send_event(self.EVENT_MEDIA_EOF)
 
-        elif (cmd == src.OBS_NEW_STREAM_TRACK):
-            ctx, title = args
+        elif (cmd == src.OBS_TAG_INFO):
+            ctx, tags = args
+            title = tags.get("TITLE", "-")
             self.__title.set_text(title)
             
 
@@ -359,7 +365,6 @@ class AudioWidget(MediaWidget):
             #if (item == self.__current_file): return
 
             self.__player = mediaplayer.get_player_for_mimetype(item.mimetype)
-            self.__player.set_options("-novideo")
             
             uri = item.get_resource()
             if (not uri.startswith("/") and
