@@ -13,7 +13,8 @@ SHUFFLE_MODE_ALL = "all"
 
 
 _cfg = Config("",
-              [("current_viewer", Config.STRING, ""),
+              [("current_device", Config.STRING, ""),
+               ("current_viewer", Config.STRING, ""),
                ("mediaroot", Config.STRING_LIST,
                              ["/home/user/MyDocs/.videos",
                               "/home/user/MyDocs/.sounds",
@@ -23,6 +24,7 @@ _cfg = Config("",
                ("shuffle_mode", Config.STRING, SHUFFLE_MODE_NONE),
                ("scan_at_startup", Config.BOOL, True),
                ("scan_with_inotify", Config.BOOL, True),
+               ("store_thumbnails_on_medium", Config.BOOL, True),
                ("thumbnails_folder", Config.STRING, 
                               os.path.expanduser("~/.thumbnails/mediabox")),
                ("theme", Config.STRING, "default"),
@@ -30,6 +32,16 @@ _cfg = Config("",
              )
 
 
+def current_device():
+
+    return _cfg["current_device"]
+    
+
+def set_current_device(v):
+
+    _cfg["current_device"] = v
+
+
 def current_viewer():
 
     return _cfg["current_viewer"]
@@ -111,6 +123,16 @@ def set_scan_with_inotify(v):
     _cfg["scan_with_inotify"] = v
 
 
+def store_thumbnails_on_medium():
+
+    return _cfg["store_thumbnails_on_medium"]
+    
+    
+def set_store_thumbnails_on_medium(v):
+
+    _cfg["store_thumbnails_on_medium"] = v
+
+
 def thumbdir():
 
     return _cfg["thumbnails_folder"]
