@@ -1,11 +1,15 @@
 """
-The File object represents a file or folder on a storage device.
+Class for representing a file or folder on a storage device.
 """
 
 import md5
 
 
 class File(object):
+    """
+    Class for representing a file or folder on a storage device.
+    Do not subclass this class.
+    """
 
     FILE = "application/x-other"
     """MIME type for unknown file types"""
@@ -74,6 +78,8 @@ class File(object):
         """URI for accessing the file"""
 
         
+        self.__medium = None
+        
         self.child_count = 0
         self.emblem = None
         
@@ -89,6 +95,11 @@ class File(object):
 
 
     def __repr__(self):
+        """
+        Returns a readable representation of this File for debugging purposes.
+        
+        @return: readable representation
+        """
     
         return "<" + self.full_path + ">"
 
@@ -122,20 +133,56 @@ class File(object):
 
     
 
+    def __set_thumbnail_md5(self, v):
+    
+        self.__thumbnail_md5 = v
+        
+
     def __get_thumbnail_md5(self):
     
         try:
             return self.__thumbnail_md5
         except:
             return self.md5
-            
-    def __set_thumbnail_md5(self, v):
-    
-        self.__thumbnail_md5 = v
 
     thumbnail_md5 = property(__get_thumbnail_md5, __set_thumbnail_md5)
     """read-write: MD5 sum for uniquely identifying the file's thumbnail preview"""
 
+
+    def __get_medium(self):
+    
+        if (self.__medium): return self.__medium
+        
+        uri = self.resource
+        
+        if (not self.is_local):
+            return None
+        
+        elif (not uri.startswith("/")):
+            return None
+            
+        else:
+            try:
+                mounts = open("/proc/mounts", "r").readlines()
+            except:
+                return None
+            
+            longest = ""
+            for line in mounts:
+                parts = line.split()
+                mountpoint = parts[1]
+                if (uri.startswith(mountpoint)):
+                    if (len(mountpoint) > len(longest)):
+                        longest = mountpoint
+            #end for
+            self.__medium = longest
+            return longest or None
+        #end if
+        
+        return None
+
+    medium = property(__get_medium)
+    """read-only: path of the medium where the file is on (local files only)"""
        
         
     def new_file(self):
@@ -161,6 +208,7 @@ class File(object):
     def get_children(self):
         """
         Returns a list of children of this folder.
+        @deprecated: L{get_children_async} should be used instead
         
         @return: list of File objects
         """
@@ -174,7 +222,7 @@ class File(object):
         given callback handler on every file. Terminates with a None object.
         
         @param cb: callback handler
-        @param *args: variable list of arguments to the callback handler
+        @param args: variable list of arguments to the callback handler
         """
         
         self.__device.ls_async(self.path, cb, *args)
@@ -189,7 +237,7 @@ class File(object):
         @param maxlen: number of bytes to retrieve or -1 for retrieving the
                        whole file
         @param cb:     callback handler for accepting the data chunks
-        @param *args:  variable list of arguments to the callback handler
+        @param args:  variable list of arguments to the callback handler
         """
         
         self.__device.load(self, maxlen, cb, *args)
